[![PyPI Version](https://badge.fury.io/py/matchor.svg)](https://badge.fury.io/py/matchor)
[![Python Build](https://github.com/nbiotcloud/matchor/actions/workflows/main.yml/badge.svg)](https://github.com/nbiotcloud/matchor/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/matchor/badge/?version=stable)](https://matchor.readthedocs.io/en/stable/?badge=stable)
[![Coverage Status](https://coveralls.io/repos/github/nbiotcloud/matchor/badge.svg?branch=main)](https://coveralls.io/github/nbiotcloud/matchor?branch=main)
[![python-versions](https://img.shields.io/pypi/pyversions/matchor.svg)](https://pypi.python.org/pypi/matchor)
[![pylint](https://img.shields.io/badge/linter-pylint-%231674b1?style=flat)](https://www.pylint.org/)
[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# Extended Pattern Matching

* [Documentation](https://matchor.readthedocs.io/en/stable/)
* [PyPI](https://pypi.org/project/matchor/)
* [Sources](https://github.com/nbiotcloud/matchor)
* [Issues](https://github.com/nbiotcloud/matchor/issues)

## Installation

Installing it is pretty easy:

```bash
pip install matchor
```
